
import sys
import os

# kivy to not parse args, will work in kivy 1.9
os.environ['KIVY_NO_ARGS'] = '1'

#prevent imports from using stdout/stderr until we've set them up
didredirectstd = False
sys.stderr = open(os.devnull, 'w')
sys.stdout = open(os.devnull, 'w')

from application.lib.freezerutils import isFrozen
from application import devmode

# test write permission
if sys.platform == 'win32':
    from application.lib.adminmode import is_admin
    from application.lib.adminmode import filewritetest
    from application.lib.adminmode import elevate

    if not is_admin():
        if not filewritetest():
            elevate(isfrozen=isFrozen())
            sys.exit()

    # from freezerutils import isFrozen
    # suppress py2exe generation of log messages
    if isFrozen():
        if not devmode:
            try:
                #Frozen, put log on same level as launching main.exe
                sys.stderr = open('../log.txt', 'w')
                sys.stdout = open('../log.txt', 'w')
                didredirectstd = True
            except:
                #Frozen, route all output to blackhole
                sys.stderr = open(os.devnull, 'w')
                sys.stdout = open(os.devnull, 'w')
                didredirectstd = True

if sys.platform == 'darwin':    
    #output to error console
    if isFrozen():
        if not devmode:
            #Frozen, route all output to blackhole, mac struggles with output to
            #console in production mode, especially with long strings, can pass in testing
            #but crash when frozen and deployed, this is safest
            #sys.stderr = open(os.devnull, 'w')
            #sys.stdout = open(os.devnull, 'w')
            pass

if not didredirectstd:
    sys.stdout = sys.__stdout__
    sys.stderr = sys.__stderr__

from application import __version__

print '==TitanVideo=='
print __version__


#### UPDATE PATHS ####
if sys.platform == 'win32':
    if isFrozen():
        dllspath = os.path.abspath('./dlls')
        #os.environ['PATH'] = os.environ['PATH'] +';'+dllspath
        os.environ['PATH'] = dllspath+';'+os.environ['PATH']  #our path in front
        sys.path.insert(0, dllspath)
    else:
        pass


#update darwin path
if sys.platform == 'darwin':


    if isFrozen():    
        #these are copied in by setup.py, include them in the path!
        #local dylibs first
        frameworkspath = os.path.abspath('../Frameworks')
        os.environ['PATH'] = os.environ['PATH'] +';'+frameworkspath
        sys.path.insert(0, frameworkspath)

        #brew install, sometimes core things are missing from end, add to back of path
        brewpath = os.path.abspath('./brewlib')
        os.environ['PATH'] = os.environ['PATH'] +';'+brewpath
        sys.path.append(brewpath) #end
        brewpath = os.path.abspath('./brewlib/lib-dynload')
        os.environ['PATH'] = os.environ['PATH'] +';'+brewpath
        sys.path.append(brewpath) #end

        #provide path to boto cert
        os.environ['BOTO_CONFIG'] = 'botoconfig/botoconfig.txt'

    else: #if not isFrozen():

        #REMOVE BREW PATHS SO DEPLOYMENT AND DEV MATCH 
        #import re
        #elsys = []
        #for path in sys.path:
        #    m = re.search('cellar', path, flags=re.I)
        #    if not m:
        #        elsys.append(path)
        #    else:
        #        print 'REMOVING PATH:'+str(path)
        #sys.path = elsys #set path

        #include brewpath, which is just a copy of brew files, these are included in deployment
        brewpath = os.path.abspath('./macosx/brewlib')
        os.environ['PATH'] = os.environ['PATH'] +';'+brewpath
        sys.path.append(brewpath) #end
        brewpath = os.path.abspath('./macosx/brewlib/lib-dynload')
        os.environ['PATH'] = os.environ['PATH'] +';'+brewpath
        sys.path.append(brewpath) #end


#launch kivy
import kivy
from kivy.utils import platform as kivyplatform

from application import temppath
from application import sandboxpath
from application.lib.unicodehelper import uni2str as str


# Make sure we have a single instance running
# https://github.com/pycontribs/tendo, strip out crap
from application.lib.tendosingleton import SingleInstance
if sys.platform == 'win32':
    from application.lib.sandbox import SandboxPath
    issingleton = True
    lockpath = SandboxPath() + '/' + 'titanvideo.lock'
    print 'LOCKPATH:'+str(lockpath)
    try:
        needthisvar = SingleInstance(lockfile = lockpath)
    except:
        issingleton = False
if sys.platform == 'darwin':
    #this only works when frozen
    issingleton = True
    try:
        needthisvar = SingleInstance()
    except:
        issingleton = False
print 'ISSINGLETON:'+str(issingleton)



#set window_icon
from kivy.config import Config
if kivyplatform in ['macosx', 'ios']:
    Config.set('kivy', 'window_icon', 'static/titanvideo.icns')
if kivyplatform in ['win', 'linux', 'android']:
    Config.set('kivy', 'window_icon', 'static/titanvideo.ico')


#desktop settings
if kivyplatform in ['macosx', 'win', 'linux']:
    Config.set('kivy', 'desktop', 1)
    Config.set('kivy', 'pause_on_minimize', 1)

#size
if kivyplatform in ['win', 'linux', 'macosx']:
    from kivy.core.window import Window
    #Window.size = (500,600)
    Config.set('graphics', 'height', 800)
    Config.set('graphics', 'width', 800)
    Window.size = (800, 800)

    #Window.borderless = False
    #Config.set('graphics', 'borderless', 0)

    #HACK windows in tablet mode shrinks it down if i make it resizable...
    #Window.resizable = False
    #Config.set('graphics', 'resizable', 0)
    #Window.resizable = True
    #Config.set('graphics', 'resizable', 1)

    #Window.fullscreen = False
    Config.set('graphics', 'fullscreen', 0)
    Config.set('graphics', 'multisamples', '0')


Config.write()
   

#set android egg path to writeable area
if kivyplatform in ['android']:
    if os.environ.get('ANDROID_APP_PATH'):
        os.environ['PYTHON_EGG_CACHE'] = os.environ.get('ANDROID_APP_PATH')

#import platform
from application.lib.logger import Logger
from application import cleanup

if __name__ == '__main__':

    logger = Logger(__name__)

    logger.info('==========START===========')
    logger.info('PATH: ' + os.getcwd())
    if kivyplatform in ['android']:
        logger.info('ANDROID_APP_PATH ' + os.environ.get('ANDROID_APP_PATH'))
    logger.info('VERSION ' + __version__)
    logger.info('ISFROZEN ' + str(isFrozen()))
    logger.info('KIVYPLATFORM:' + str(kivyplatform))
    try:
        logger.info('SANDBOX:' + sandboxpath)
        logger.info('SANDBOXTEMP:' + temppath)
    except:
        pass
    logger.info('ENVIRON PATH:')
    for path in os.environ['PATH'].split(';'):
        logger.info(path)
    logger.info('SYS PATH:')
    for path in sys.path:
        logger.info('\t'+path)
    cleanup()
    if kivyplatform in ['android']:
        from application.android.sysinfo import manufacturer
        from application.android.sysinfo import model
        from application.android.sysinfo import sdk
        from application.android.sysinfo import codename
        from application.android.sysinfo import release
        from application.android.sysinfo import androidid
        from application.android.sysinfo import unknownsources
        logger.info('ANDROID Manufacturer:' + str(manufacturer))
        logger.info('ANDROID Model:' + str(model))
        logger.info('ANDROID SDK:' + str(sdk))
        logger.info('ANDROID CODENAME:' + str(codename))
        logger.info('ANDROID RELEASE:' + str(release))
        logger.info('ANDROID ID:' + str(androidid))
        logger.info('ANDROID UNKNOWN SOURCES:' + str(unknownsources)) 
    #logger.info('WINDOW SIZE:' + str(Window.size))

    # FSM in thread
    if kivyplatform == 'android':
       from application.android.pyserial_javawrappers import android_serial_preinit
       android_serial_preinit()

    from application.mainapp import MainApp
    MainApp().run()

