
;--------------------------------
;Include Modern UI

  !include "MUI2.nsh"
  !addplugindir "${NSISDIR}\Plugins"

  !define MUI_ICON "../static/titanvideo.ico"

;include 64 v 32 bit detection
  !include "x64.nsh"
  
;--------------------------------
;General

  ;Name and file
  Name "TitanVideo"
  OutFile "TitanVideoInstaller.exe"

  ;Default installation folder
  InstallDir "$LOCALAPPDATA\TitanVideo"
  
  ;Get installation folder from registry if available
  InstallDirRegKey HKCU "Software\TitanVideo" ""

  ;Request application privileges for Windows Vista
  ;RequestExecutionLevel user
  RequestExecutionLevel admin

;--------------------------------
;Variables

  Var StartMenuFolder
  ;!define TITANVIDEO_ZIP "TitanVideo-3.0.0.win32.zip" ;variable passed when calling this script

;--------------------------------
;Interface Settings

  !define MUI_ABORTWARNING

;--------------------------------
;Pages

  !insertmacro MUI_PAGE_LICENSE "license.txt"
  ;!insertmacro MUI_PAGE_COMPONENTS
  ;!insertmacro MUI_PAGE_DIRECTORY
 


  ;Start Menu Folder Page Configuration
  !define MUI_STARTMENUPAGE_REGISTRY_ROOT "HKCU" 
  !define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\TitanVideo" 
  !define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"
  
  !insertmacro MUI_PAGE_STARTMENU Application $StartMenuFolder

  !insertmacro MUI_PAGE_INSTFILES
  
  !insertmacro MUI_UNPAGE_CONFIRM
  !insertmacro MUI_UNPAGE_INSTFILES
  
;--------------------------------
;Languages
 
  !insertmacro MUI_LANGUAGE "English"

;--------------------------------
;Installer Sections

Section "TitanVideo Application (required)" SecTitanVideo

    SectionIn RO

    SetOutPath "$INSTDIR"
    
    ;The context of this constant (All Users or Current user) 
    SetShellVarContext all

    ;install ZIP
    File "nsis_includes\\7z\\7za.exe" 
    File "nsis_includes\\7z\\7za.dll"
    File "nsis_includes\\7z\\7zxa.dll"

    File "${TITANVIDEO_ZIP}"

    ExecWait "7za.exe x -aoa ${TITANVIDEO_ZIP}"


    ;create desktop shortcut
    CreateShortCut "$DESKTOP\TitanVideo.lnk" "$INSTDIR\main.exe" ""

    !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
    ;Create shortcuts
    CreateDirectory "$SMPROGRAMS\$StartMenuFolder"
    CreateShortcut "$SMPROGRAMS\$StartMenuFolder\Log.lnk" "$INSTDIR\log.txt"
    CreateShortcut "$SMPROGRAMS\$StartMenuFolder\Uninstall.lnk" "$INSTDIR\Uninstall.exe"
    CreateShortcut "$SMPROGRAMS\$StartMenuFolder\TitanVideo.lnk" "$INSTDIR\main.exe"
    !insertmacro MUI_STARTMENU_WRITE_END

    ;Add/Remove Programs entry
    ;https://stackoverflow.com/questions/5028309/how-do-i-add-the-program-in-windows-add-remove-program-list
    !define REGUNINSTKEY "TitanVideo" ;Using a GUID here is not a bad idea
    !define REGHKEY HKLM ;Assuming RequestExecutionLevel admin AKA all user/machine install
    !define REGPATH_WINUNINST "Software\Microsoft\Windows\CurrentVersion\Uninstall"
    WriteRegStr ${REGHKEY} "${REGPATH_WINUNINST}\${REGUNINSTKEY}" "DisplayName" "TitanVideo"
    WriteRegStr ${REGHKEY} "${REGPATH_WINUNINST}\${REGUNINSTKEY}" "UninstallString" '"$INSTDIR\Uninstall.exe"'
    WriteRegStr ${REGHKEY} "${REGPATH_WINUNINST}\${REGUNINSTKEY}" "DisplayIcon " "${MUI_ICON}"
    
    ;Create uninstaller
    WriteUninstaller "$INSTDIR\Uninstall.exe"
    
SectionEnd

;--------------------------------
;Descriptions

  ;Language strings
  LangString DESC_SecTitanVideo ${LANG_ENGLISH} "This installs TitanVideo."

  ;Assign language strings to sections
  !insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
    !insertmacro MUI_DESCRIPTION_TEXT ${SecTitanVideo} $(DESC_SecTitanVideo)
  !insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;Uninstaller Section

Section "Uninstall"

    ;The context of this constant (All Users or Current user) 
    SetShellVarContext all

    ;Delete Files 
    RMDir /r "$INSTDIR\*.*"    
    
    ;Remove the installation directory
    RMDir "$INSTDIR"

    !insertmacro MUI_STARTMENU_GETFOLDER Application $StartMenuFolder
    Delete "$SMPROGRAMS\$StartMenuFolder\Uninstall.lnk"
    Delete "$SMPROGRAMS\$StartMenuFolder\Log.lnk"
    Delete "$SMPROGRAMS\$StartMenuFolder\TitanVideo.lnk"
    RMDir "$SMPROGRAMS\$StartMenuFolder"
    
    ;create desktop shortcut
    Delete "$DESKTOP\TitanVideo.lnk"

    ;remove from add/remove programs
    DeleteRegKey  ${REGHKEY} "${REGPATH_WINUNINST}\${REGUNINSTKEY}"

SectionEnd
