#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys,os

from win.eskyinstaller.helper import globber, getver, getdebugmode

__appname__ = "HeadsUpApp"
mainpy = "headsupapp.py"
debugmode = getdebugmode()
if debugmode:
    __appname__ = __appname__+'DEV'

#weird version from file is to trick esky
__version__ = getver()

if __name__ == "__main__":

    #linux
    if sys.platform in ['linux2']:
        from distutils.core import setup
        from esky.bdist_esky import Executable

        exe = Executable(mainpy)

        setup(
            name = __appname__,
            version = __version__,
            description="Hello world",
            author="stephane smith",
            scripts = [exe],
            data_files = [],
            options = {"bdist_esky" :{
                        "includes" : [],
                        "freezer_module": "cxfreeze"},
                    },
        )

    #windows
    if sys.platform in ['win32','cygwin','win64']:
        from distutils.core import setup
        from esky.bdist_esky import Executable
        from eskyinstaller.hooks import hiddenimports

        datafiles = []
        datafiles += globber('application', 'application', ['.+\.kv$'])
        datafiles += globber('static', 'static', ['.+\.png$', '.+\.ico$','.+\.ttf'])
        datafiles += globber('kivy/data', 'C:\Kivy\kivy\kivy\data', ['.+\.*$'])
        datafiles += globber('pygame', 'C:\Kivy\Python27\Lib\site-packages\pygame',
                            ['.+\.dll$', '.+\.ttf$', '.+\.icns$', '.+\.pyd$'])

        for datafile in datafiles:
            print datafile

        freezer = 'py2exe'
        freezer_options = {
            'includes': ['application', 'esky']+hiddenimports,
            'packages': ['kivy', 'pygame', 'esky'],
            'skip_archive':True,
            'dest_name': 'headsupapp',
        }

        exe = Executable(mainpy,
                        icon='static/headsupapp.ico', #icon size largest to smallest
                        gui_only=not debugmode)

        esky_options = {'freezer_module':freezer,
                        'freezer_options':freezer_options,
                        'includes':[],
                        'excludes':[]}
        setup(
            name = __appname__,
            version = __version__,
            scripts = [exe],
            data_files = datafiles,
            options = {'bdist_esky':esky_options,
                    freezer:freezer_options},
            )

    #osx
    if sys.platform == 'darwin':

        freezer = 'py2app'
        freezer_options = {
            'argv_emulation': True,
            'iconfile': 'static/headsupapp.icns',
            'includes': ['application', 'service'],
            'packages': ['kivy','pygame','PIL'],
            #'frameworks': ['CoreFoundation', 'Foundation', 'AppKit'],#['SDL2_ttf'],
            'frameworks': [],
            'plist':{'CFBundleIconFile':'headsupapp.icns',
                    'CFBundleIdentifier':'com.integratedbionics.HeadsUpApp',
                    'LSApplicationCategoryType':'public.app-category.sports',
                    'NSHumanReadableCopyright':u'\u00a9 Integrated Bionics, Inc',
                    }
        }

        datafiles = []
        datafiles += globber('application', 'application', ['.+\.kv$'])
        datafiles += globber('static', 'static', ['.+\.png$', '.+\.ico$', '.+\.icns$', '.+\.ttf'])
        #datafiles += globber('lib/python2.7/PIL', '/Library/Python/2.7/site-packages/PIL', ['.+\.*$'])

        if 'py2app' in sys.argv:
            from setuptools import setup

            setup(
                    name = __appname__,
                    version = __version__,
                    url = 'http://www.integratedbionics.com',
                    description = 'HeadsUp Application by Integrated Bionics, Inc',
                    app = [mainpy],
                    packages = [],
                    data_files = datafiles,
                    options = {
                            freezer:freezer_options},
                    setup_requires=[freezer],
                )
    
        if 'bdist_esky' in sys.argv:
            from setuptools import setup
            from esky.bdist_esky import Executable

            exe = [Executable(mainpy,
                            icon='static/headsupapp.icns',
                            gui_only=not debugmode)]

            esky_options = {'freezer_module':freezer,
                            'freezer_options':freezer_options,
                            'includes':['kivy'],
                            'excludes':[]}

            setup(
                    name = __appname__,
                    version = __version__,
                    url = 'http://www.integratedbionics.com',
                    description = 'HeadsUp Application by Integrated Bionics, Inc',
                    scripts = exe,
                    app = [mainpy],
                    packages = [],
                    data_files = datafiles,
                    options = {'bdist_esky':esky_options,
                            freezer:freezer_options},
                    setup_requires=[freezer],
                )

